#!/usr/bin/env python3
import time
from pprint import pprint
from .agent_based_api.v1 import get_value_store, get_rate, register, render, Service, Result, State, Metric

# just a simple service withoot item
def discover_hal9001_status(section):
    yield(Service())

def check_hal9001_status(section):
    status = section["status"]
    version = section["version"]
    username = section["username"]
    ipaddress = section["ipaddress"]
    # check what status is reported and set state accordingly
    if status == "ok":
        state = State.OK
    elif status == "update available":
        state = State.WARN
    elif status == "storage down":
        state = State.CRIT
    else:
        state = State.UNKOWN
    # no metrics, just a simple service
    summary = f'Status is "{status}", Version is "{version}"'
    details = f'User/IP used for access is "{username}/{ipaddress}"'
    yield(Result(state=state, summary=summary, details=details))

def parse_hal9001_status_section(string_table):    
    parsed_data = {}
    # we only expect one line with four entries
    line = string_table[0]
    parsed_data["status"] = line[0]
    parsed_data["version"] = line[1]
    parsed_data["username"] = line[2]
    parsed_data["ipaddress"] = line[3]
    return parsed_data
      
register.agent_section(
    name = "hal9001_status",
    parse_function = parse_hal9001_status_section,
)

register.check_plugin(
    name = "hal9001_status",
    service_name = "HAL Overall information",
    discovery_function = discover_hal9001_status,
    check_function = check_hal9001_status,
)