#!/usr/bin/env python3
import time
from pprint import pprint
from .agent_based_api.v1 import get_value_store, get_rate, register, render, Service, Result, State, Metric

def getStateUpper(levels, value):
    warn, crit = levels
    if value >= crit:
        return State.CRIT
    if value >= warn:
        return State.WARN
    return State.OK

# services with item --> userid
def discover_hal9001_users(section):
    for key in section:
        yield(Service(item = key))

def check_hal9001_users(item, params, section):
    userid = item
    # get all values from section
    realname = section[userid][0]
    used_bytes = section[userid][1]
    quota_max_bytes = section[userid][2]
    # calculate percentage of max quota used
    quota_used_percent = used_bytes * 100 / quota_max_bytes
    # create a graph with storage usage in percent of max quota
    levels = params["levels_hal_users_quota_used"]
    yield Metric("hal_users_quota_used", quota_used_percent, levels=levels)
    # calculate state of service based on levels given as parameter
    state = getStateUpper(levels, quota_used_percent)
    summary = f"Used quota of {realname} is {render.percent(quota_used_percent)}, {render.disksize(used_bytes)} of {render.disksize(quota_max_bytes)} used"
    yield(Result(state=state, summary=summary))

def parse_hal9001_users_section(string_table):    
    # convert the raw output of the agent section in an meaningful structure, do type conversions and so on
    parsed_data = {}
    for line in string_table:
        userid = line[0]
        realname = line[1]
        quota_used = float(line[2])
        quota_total = float(line[3])
        parsed_data[f"{userid}"] = [realname, quota_used, quota_total]
    return parsed_data
      
register.agent_section(
    name = "hal9001_users",
    parse_function = parse_hal9001_users_section,
)

register.check_plugin(
    name = "hal9001_users",
    service_name = "HAL User information %s",
    discovery_function = discover_hal9001_users,
    check_function = check_hal9001_users,
    check_default_parameters = {
        "levels_hal_users_quota_used": (65.0, 85.0),
    },
    check_ruleset_name="hal9001_users_storage_levels",
)